package com.dzeio.openhealth.data.weight

import androidx.room.ColumnInfo
import androidx.room.Entity
import androidx.room.PrimaryKey
import java.sql.Date
import java.text.DateFormat.getDateInstance

@Entity()
data class Weight(
    @PrimaryKey(autoGenerate = true)
    var id: Long = 0,
    /**
     * Store the weight in kilograms
     */
    var weight: Float = 0f,

    /**
     * when the weight was taken precise to the millisecond
     */
    @ColumnInfo(index = true)
    var timestamp: Long = System.currentTimeMillis(),

    /**
     * the source for the Entry
     *
     * note: Unused currently but kept for future usage
     */
    var source: String = "OpenHealth",

    /**
     * The BMI
     *
     * calculated from the height and Weight of the user
     *
     * ex: weight / (height(cm)/100)²
     */
    var bmi: Float? = null,

    /**
     * the total body water (tbw) in percents
     *
     * can be estimated
     * https://www.mdapp.co/total-body-water-tbw-calculator-448/
     */
    var totalBodyWater: Float? = null,

    /**
     * the Muscle weight in percents
     */
    var muscles: Float? = null,

    /**
     * the lean Body Mass in percents
     */
    var leanBodyMass: Float? = null,

    /**
     * the Body Fat in percents
     */
    var bodyFat: Float? = null,

    /**
     * the bone Mass in Percents
     */
    var boneMass: Float? = null,

    /**
     * visceral fat in it's own unit?
     */
    var visceralFat: Float? = null
) {
    fun formatTimestamp(): String = getDateInstance().format(Date(timestamp))

    override fun equals(other: Any?): Boolean {
        if (!(other is Weight)) {
            return super.equals(other)
        }

        return weight == other.weight &&
            timestamp == other.timestamp &&
            bmi == other.bmi &&
            totalBodyWater == other.totalBodyWater &&
            muscles == other.muscles &&
            leanBodyMass == other.leanBodyMass &&
            bodyFat == other.bodyFat &&
            boneMass == other.boneMass &&
            visceralFat == other.visceralFat
    }
}
