package com.dzeio.openhealth.ui.water

import android.view.LayoutInflater
import android.view.View
import androidx.core.widget.doOnTextChanged
import com.dzeio.openhealth.R
import com.dzeio.openhealth.Settings
import com.dzeio.openhealth.core.BaseDialog
import com.dzeio.openhealth.databinding.DialogWaterSizeSelectorBinding
import dagger.hilt.android.AndroidEntryPoint

@AndroidEntryPoint
class WaterSizeSelectorDialog :
    BaseDialog<WaterSizeSelectorViewModel, DialogWaterSizeSelectorBinding>(
        WaterSizeSelectorViewModel::class.java
    ) {

    override val bindingInflater: (LayoutInflater) -> DialogWaterSizeSelectorBinding
        get() = DialogWaterSizeSelectorBinding::inflate

    override fun onCreated() {
        super.onCreated()

        binding.cancel.setOnClickListener {
            dismiss()
        }

        binding.validate.setOnClickListener {
            dismiss()
        }

        viewModel.cupSize.observe(this) {
            var real = it ?: Settings.WATER_INTAKE_SIZE_DEFAULT
            binding.customSize.text = String.format(
                getString(R.string.custom_amount),
                "${real}ml"
            )
            if (binding.inputParent.visibility == View.GONE) {
                binding.input.setText(real.toString())
            }
        }

        binding.size100ml.setOnClickListener {
            setTextFieldStatus()
            viewModel.setCupSize(100)
        }
        binding.size250ml.setOnClickListener {
            setTextFieldStatus()
            viewModel.setCupSize(250)
        }
        binding.size500ml.setOnClickListener {
            setTextFieldStatus()
            viewModel.setCupSize(500)
        }
        binding.size1000ml.setOnClickListener {
            setTextFieldStatus()
            viewModel.setCupSize(1000)
        }

        binding.customSize.setOnClickListener {
            setTextFieldStatus(true)
        }

        binding.input.doOnTextChanged { text, start, before, count ->
            val newSize = text.toString().toIntOrNull()
            if (newSize != null) {
                viewModel.setCupSize(newSize)
            }
        }
    }

    private fun setTextFieldStatus(displayed: Boolean = false) {
        binding.inputParent.visibility = if (displayed) View.VISIBLE else View.GONE
        binding.customSize.visibility = if (displayed) View.GONE else View.VISIBLE
    }
}
